from urllib import parse
import urllib,pygame
import contextlib
import wave
import urllib.request
import requests,json
import time
from os import path
from urllib.request import urlopen
from urllib.parse import urlencode
from urllib.parse import quote_plus
import hashlib
import random
import base64
import json,time
speaker=1
ak=urllib.request.urlopen("http://www.asunc.cn/ak.txt").read().decode("utf-8")
ak=json.loads(ak)['ak']
def setvoicemode(gender):
    if gender != "boy" and gender != "girl":
        raise Exception("参数必须为boy(男人)或者girl(女人)")
    if gender=='boy':
        speaker=1
    if gender=='girl':
        speaker=5
def get_ipaddress(ip, getpoint=False):
    if ip.count(".") != 3:
        return -1
    else:
        url = 'http://api.map.baidu.com/location/ip?ak=' + ak + '&ip=' + urllib.parse.quote(ip) + '&coor=bd09ll'
        address = urllib.request.urlopen(url).read().decode("utf-8")
        if 0:
            return -1
        else:
            address = json.loads(address)
            if address['status'] == 0:
                if getpoint==True:
                    content = address['content']
                    addrpoint = content['point']
                    return content['address'], addrpoint['x'], addrpoint['y']
                else:
                    content = address['content']
                    return content['address']

            else:
                return -1
def get_traffic(road,city):
    url='http://api.map.baidu.com/traffic/v1/road?road_name='+urllib.parse.quote(road)+'&city='+urllib.parse.quote(city)+'&ak='+ak
    address = urllib.request.urlopen(url).read().decode("utf-8")
    address = json.loads(address)
    if address['status']==0:
        return address['description']
    else:
        return -1
def makevoice(text, filename,mode=1,speed=40):
    def getReqSign(params, key):
        dict_kl = sorted(params)
        s = ''
        for k in dict_kl:
            v = params[k]
            if v != '':
                v0 = str(quote_plus(str(v)))
                s = s + k + '=' + v0 + '&'
        s = s + 'app_key=' + key;
        m = hashlib.md5()
        m.update(s.encode("utf8"))
        sign = m.hexdigest()
        sign = sign.upper()
        return sign
    app=json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
    appid = app['appid']
    appkey = app['appkey']
    url = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tts'
    time_s = int(time.time())
    m = hashlib.md5()
    m.update(str(time_s).encode("utf8"))
    nonce_s = m.hexdigest()
    nonce_s = nonce_s[0:random.randint(1, 31)]
    vmv='1'
    if filename[len(filename)-4]=='.':
        if filename[len(filename)-3]=='p' or filename[len(filename)-3]=='P':
            wmv='1'
        elif filename[len(filename)-3]=='w' or filename[len(filename)-3]=='W':
            wmv='2'
        elif filename[len(filename)-3]=='m' or filename[len(filename)-3]=='M':
            wmv='3'

    params = {'app_id': appid,
              'speaker': mode,
              'format': wmv,
              'volume': '0',
              'speed': speed * 2,
              'text': text,
              'aht': '0',
              'apc': '58',
              'time_stamp': time_s,
              'nonce_str': nonce_s,
              'sign': ''
              }
    params['sign'] = getReqSign(params, appkey)
    s = urlencode(params)
    res = urlopen(url, s.encode())  # 网络请求
    res_str = res.read().decode()
    res_dict = eval(res_str)

    if res_dict['ret'] == 0:
        res_data = res_dict['data']
        res_data_format = res_data['format']
        res_data_speech = res_data['speech']
        res_data_md5sum = res_data['md5sum']
        filepath = path.dirname(__file__)  # 目录
        file = '/wav01.wav'
        base64_data = res_data_speech
        ori_image_data = base64.b64decode(base64_data)
        fout = open(filename, 'wb')
        fout.write(ori_image_data)
        fout.close()
        return res_dict['ret']
    else:
        return res_dict['ret']
def speak(text,mode=1,speed=40):
    def getReqSign(params, key):
        dict_kl = sorted(params)
        s = ''
        for k in dict_kl:
            v = params[k]
            if v != '':
                v0 = str(quote_plus(str(v)))
                s = s + k + '=' + v0 + '&'
        s = s + 'app_key=' + key;
        m = hashlib.md5()
        m.update(s.encode("utf8"))
        sign = m.hexdigest()
        sign = sign.upper()
        return sign
    app=json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
    appid = app['appid']
    appkey = app['appkey']
    url = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tts'
    time_s = int(time.time())
    m = hashlib.md5()
    m.update(str(time_s).encode("utf8"))
    nonce_s = m.hexdigest()
    nonce_s = nonce_s[0:random.randint(1, 31)]
    params = {'app_id': appid,
              'speaker': mode,
              'format': '2',
              'volume': '0',
              'speed': speed*2,
              'text': text,
              'aht': '0',
              'apc': '58',
              'time_stamp': time_s,
              'nonce_str': nonce_s,
              'sign': ''
              }
    params['sign'] = getReqSign(params, appkey)
    s = urlencode(params)
    res = urlopen(url, s.encode())  # 网络请求
    res_str = res.read().decode()
    res_dict = eval(res_str)
    if res_dict['ret'] == 0:
        res_data = res_dict['data']
        res_data_format = res_data['format']
        res_data_speech = res_data['speech']
        res_data_md5sum = res_data['md5sum']
        filepath = path.dirname(__file__)  # 目录
        file = '/wav01.wav'
        base64_data = res_data_speech
        ori_image_data = base64.b64decode(base64_data)
        try:
            with open('alsovoice.wav', "wb") as f:
                f.write(ori_image_data)
            f.close()
            import wave
            fr = wave.open('alsovoice.wav', 'rb')
            secs = fr.getnframes() / fr.getframerate()
            pygame.mixer.init()
            pygame.mixer.music.load("alsovoice.wav")
            pygame.mixer.music.play()
            time.sleep(secs+0.1)
            return res_dict['ret']
        except:
            return -1
    else:
        return res_dict['ret']
def help():
    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt"))


import time
import zxing
from socket import*
from email.mime.text import MIMEText
from random import*
import smtplib
import requests
import json
from cefpython3 import cefpython as cef
import platform
import sys
import urllib.request ,re,os
import time
from re import*
import requests
from urllib.request import*
import json
def getversion():
    return "0.4.5"
def cleardevice():
    print("\033[2J")
    print("\033[99999999999999999999999999999999A", end='')
def baidubaike(text):
    html=urllib.request.urlopen("http://gop.asunc.cn/baike.html").read().decode("utf-8")
    url=html+urllib.parse.quote(text)
    html=urllib.request.urlopen(url).read().decode("utf-8")
    par = '(<meta name="description" content=")(.*?)(">)'
    try:
        data = re.search(par,html).group(2)
        return data
    except:
        return -1
def translate(string):
    data = {'doctype': 'json','type': 'AUTO','i':string}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    result = result['translateResult'][0][0]["tgt"]
    return result
def getweather(province,city):
    tf=0
    data = {'doctype': 'json','type': 'AUTO','i':province}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    province = result['translateResult'][0][0]["tgt"]
    data = {'doctype': 'json','type': 'AUTO','i':city}
    url = "http://fanyi.youdao.com/translate"
    r = requests.get(url,params=data)
    result = r.json()
    city = result['translateResult'][0][0]["tgt"]
    try:
        wurl="https://tianqi.moji.com/weather/china/"+province+'/'+city
        html = urllib.request.urlopen(wurl).read().decode("utf-8")
        par = '(<meta name="description" content=")(.*?)(">)'
        data = re.search(par, html).group(2)
        data = data.replace(",", "，").replace("。", "，").replace("墨迹天气建议您", "爱搜天气助手建议您")
        return data
    except:
        return -1

def get_news():
    now = time.strftime("%Y-%m-%d", time.localtime())
    print(now,"最新新闻资讯,转载于人民日报。\n")
    now = time.strftime("%Y%m%d", time.localtime())
    now1 = time.strftime("%Y-%m/%d", time.localtime())
    print("今日新闻资讯:")
    for i in range(1,10):
        try:
            url="http://paper.people.com.cn/rmrb/html/"+now1+"/nw.D110000renmrb_"+now+"_3-0"+str(i)+".htm"
            html=urlopen(url).read().decode("utf-8")
            html=html.replace("<br>","")
            html=html.replace("&nbsp;","")
            html=html.replace("<P>","")
            html=html.replace("</P>","")
            a1=html.index("<title>")+len("<title>")
            b1=html.index("</title>")
            a=html.index("<!--enpcontent-->")+19
            b=html.index("<!--/enpcontent-->")
            print(i,".",end="")
            while a1<b1:
                print(html[a1],end="")
                a1+=1
            print("\n")
        except:
            last=i-1
            break
    try:
        number=int(input("您需要的看点:"))
    except:
        return -1
    if number>last or number<1:
        return -1
    url="http://paper.people.com.cn/rmrb/html/"+now1+"/nw.D110000renmrb_"+now+"_3-0"+str(number)+".htm"
    html=urlopen(url).read().decode("utf-8")
    html=html.replace("<P>","")
    html=html.replace("</P>","")
    html=html.replace("<br>","")
    html=html.replace("&nbsp;","")
    a1=html.index("<title>")+len("<title>")
    b1=html.index("</title>")
    a=html.index("<!--enpcontent-->")+19
    b=html.index("<!--/enpcontent-->")
    print("标题:")
    while a1<b1:
        print(html[a1],end="")
        a1+=1
    print("\033[33m")
    while a1<b1:
        print(html[a1],end="")
        a1+=1
    print("\033[0m")
    print("\n内容:")
    print("\033[44m",end="  ")
    while a<b:
        print(html[a],end="")
        a+=1
    print("\033[0m")

def check_browser_versions():
    ver = cef.GetVersion()
    print("[hello_world.py] CEF Python {ver}".format(ver=ver["version"]))
    print("[hello_world.py] Chromium {ver}".format(ver=ver["chrome_version"]))
    print("[hello_world.py] CEF {ver}".format(ver=ver["cef_version"]))
    print("[hello_world.py] Python {ver} {arch}".format(
           ver=platform.python_version(),
           arch=platform.architecture()[0]))
    assert cef.__version__ >= "57.0", "CEF Python v57.0+ required to run this"
def searchweb(text,title):
    try:
        html = urllib.request.urlopen(text).read().decode("utf-8")
        sys.excepthook = cef.ExceptHook
        cef.Initialize()
        cef.CreateBrowserSync(url=text,window_title=title)
        cef.MessageLoop()
    except:
        return -1
def get_imformation(pid):
    try:
        url="http://code.xueersi.com/api/compilers/"+str(pid)+"?id="+str(pid)
        headers = {'Content-Type':'application/json'}
        a=requests.get(url=url, headers=headers)
        null,false,list_get,string=0,0,[],''
        p=json.loads(a.text)
        likes=p["data"]["likes"]
        unlikes=p["data"]["unlikes"]
        return likes,unlikes,p["data"]["username"],p["data"]["user_id"]
    except:
        return -1


from distutils.core import setup
setup(
    name="alsolib",
    version="0.5.5",
    description="学而思爱搜浏览器功能库0.5.5，下载失败请切换python原版,©爱搜浏览器团队 版权所有",
    author="asunc",
    author_email="3182305655@qq.com",
    py_modules=["alsolib\\alsolib",'alsolib\\alsoapi']
)